# Certbot PKCS#12 plugin

This is an installer plugin for [certbot](https://certbot.eff.org). Whenever
you generate a certificate with Let's Encrypt, it will save the certificate
in a [PKCS#12](https://en.wikipedia.org/wiki/PKCS_12) archive.